@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from dataclasses import field
 from enum import Enum
 from pathlib import Path
 
@@ -25,9 +26,22 @@ class ValidateDataConfig:
     ignore_duplicate_files_warning: bool
     is_on_prod_server: bool
     skip_ontology_validation: bool
+    do_not_request_resource_metadata_from_db: bool
 
 
 class ValidationSeverity(Enum):
     ERROR = 3
     WARNING = 2
     INFO = 1
+
+
+@dataclass
+class PathDependencies:
+    required_files: list[Path] = field(default_factory=list)
+    required_directories: list[Path] = field(default_factory=list)
+
+
+@dataclass
+class NetworkRequirements:
+    api_url: str
+    always_requires_docker: bool = False
