@@ -6,13 +6,6 @@ from rdflib import Literal
 from rdflib import URIRef
 
 
-@dataclass
-class RdfResourceCardinality:
-    resource_iri: URIRef
-    on_property: URIRef
-    cardinality: RdfCardinalityRestriction
-
-
 @dataclass
 class RdfCardinalityRestriction:
     owl_property: URIRef
