@@ -13,6 +13,7 @@ from dsp_tools.clients.authentication_client_live import AuthenticationClientLiv
 from dsp_tools.clients.connection import Connection
 from dsp_tools.clients.connection_live import ConnectionLive
 from dsp_tools.clients.legal_info_client_live import LegalInfoClientLive
+from dsp_tools.clients.project_client_live import ProjectInfoClientLive
 from dsp_tools.commands.ingest_xmlupload.create_resources.apply_ingest_id import get_mapping_dict_from_file
 from dsp_tools.commands.ingest_xmlupload.create_resources.apply_ingest_id import replace_filepath_with_internal_filename
 from dsp_tools.commands.validate_data.validate_data import validate_parsed_resources
@@ -24,7 +25,6 @@ from dsp_tools.commands.xmlupload.prepare_xml_input.list_client import ListClien
 from dsp_tools.commands.xmlupload.prepare_xml_input.prepare_xml_input import get_parsed_resources_and_mappers
 from dsp_tools.commands.xmlupload.prepare_xml_input.prepare_xml_input import get_stash_and_upload_order
 from dsp_tools.commands.xmlupload.prepare_xml_input.read_validate_xml_file import validate_iiif_uris
-from dsp_tools.commands.xmlupload.project_client import ProjectClientLive
 from dsp_tools.commands.xmlupload.upload_config import UploadConfig
 from dsp_tools.commands.xmlupload.xmlupload import enable_unknown_license_if_any_are_missing
 from dsp_tools.commands.xmlupload.xmlupload import execute_upload
@@ -42,7 +42,8 @@ def ingest_xmlupload(
     interrupt_after: int | None = None,
     skip_validation: bool = False,
     skip_ontology_validation: bool = False,
-    id2iri_replacement_file: str | None = None,
+    id2iri_file: str | None = None,
+    do_not_request_resource_metadata_from_db: bool = False,
 ) -> bool:
     """
     This function reads an XML file
@@ -58,7 +59,9 @@ def ingest_xmlupload(
         interrupt_after: if set, the upload will be interrupted after this number of resources
         skip_validation: skip the SHACL validation
         skip_ontology_validation: skip the ontology validation
-        id2iri_replacement_file: to replace internal IDs of an XML file by IRIs provided in this mapping file
+        id2iri_file: to replace internal IDs of an XML file by IRIs provided in this mapping file
+        do_not_request_resource_metadata_from_db: if true do not request metadata information from the api
+                                                  for existing resources
 
     Returns:
         True if all resources could be uploaded without errors; False if one of the resources could not be
@@ -83,8 +86,8 @@ def ingest_xmlupload(
     clients = _get_live_clients(con, config, auth)
 
     parsed_resources, lookups = get_parsed_resources_and_mappers(root, clients)
-    if id2iri_replacement_file:
-        parsed_resources = use_id2iri_mapping_to_replace_ids(parsed_resources, Path(id2iri_replacement_file))
+    if id2iri_file:
+        parsed_resources = use_id2iri_mapping_to_replace_ids(parsed_resources, Path(id2iri_file))
 
     validation_should_be_skipped = skip_validation
     is_on_prod_like_server = is_prod_like_server(creds.server)
@@ -115,6 +118,7 @@ def ingest_xmlupload(
                 ignore_duplicate_files_warning=True,
                 is_on_prod_server=is_on_prod_like_server,
                 skip_ontology_validation=skip_ontology_validation,
+                do_not_request_resource_metadata_from_db=do_not_request_resource_metadata_from_db,
             ),
             auth=auth,
         )
@@ -156,7 +160,7 @@ def _replace_filepaths_with_internal_filename_from_ingest(root: etree._Element,
 
 def _get_live_clients(con: Connection, config: UploadConfig, auth: AuthenticationClient) -> UploadClients:
     ingest_client = BulkIngestedAssetClient()
-    project_client = ProjectClientLive(con, config.shortcode)
-    list_client = ListClientLive(con, project_client.get_project_iri())
+    project_client = ProjectInfoClientLive(auth.server)
+    list_client = ListClientLive(con, project_client.get_project_iri(config.shortcode))
     legal_info_client = LegalInfoClientLive(config.server, config.shortcode, auth)
-    return UploadClients(ingest_client, project_client, list_client, legal_info_client)
+    return UploadClients(ingest_client, list_client, legal_info_client)
