@@ -1,23 +1,37 @@
 """This module handles the ontology creation, update and upload to a DSP server. This includes the creation and update
 of the project, the creation of groups, users, lists, resource classes, properties and cardinalities."""
 
+import os
 from pathlib import Path
 from typing import Any
+from typing import cast
 from urllib.parse import quote_plus
 
+from dotenv import load_dotenv
 from loguru import logger
 
 from dsp_tools.cli.args import ServerCredentials
 from dsp_tools.clients.authentication_client_live import AuthenticationClientLive
 from dsp_tools.clients.connection import Connection
 from dsp_tools.clients.connection_live import ConnectionLive
+from dsp_tools.clients.group_user_clients_live import GroupClientLive
+from dsp_tools.commands.create.communicate_problems import print_problem_collection
+from dsp_tools.commands.create.create_on_server.group_users import create_groups
+from dsp_tools.commands.create.create_on_server.group_users import get_existing_group_to_iri_lookup
+from dsp_tools.commands.create.create_on_server.lists import create_lists
+from dsp_tools.commands.create.create_on_server.lists import get_existing_lists_on_server
+from dsp_tools.commands.create.models.input_problems import CollectedProblems
+from dsp_tools.commands.create.models.input_problems import CreateProblem
+from dsp_tools.commands.create.models.input_problems import ProblemType
+from dsp_tools.commands.create.models.input_problems import UploadProblem
+from dsp_tools.commands.create.models.parsed_project import ParsedProject
+from dsp_tools.commands.create.models.server_project_info import GroupNameToIriLookup
+from dsp_tools.commands.create.models.server_project_info import ProjectIriLookup
+from dsp_tools.commands.create.parsing.parse_project import parse_project
 from dsp_tools.commands.project.create.parse_project import parse_project_json
 from dsp_tools.commands.project.create.project_create_default_permissions import create_default_permissions
-from dsp_tools.commands.project.create.project_create_lists import create_lists_on_server
 from dsp_tools.commands.project.create.project_create_ontologies import create_ontologies
-from dsp_tools.commands.project.create.project_validate import validate_project
 from dsp_tools.commands.project.legacy_models.context import Context
-from dsp_tools.commands.project.legacy_models.group import Group
 from dsp_tools.commands.project.legacy_models.project import Project
 from dsp_tools.commands.project.legacy_models.user import User
 from dsp_tools.commands.project.models.permissions_client import PermissionsClient
@@ -27,10 +41,14 @@ from dsp_tools.error.exceptions import InputError
 from dsp_tools.error.exceptions import InvalidInputError
 from dsp_tools.error.exceptions import PermanentConnectionError
 from dsp_tools.legacy_models.langstring import LangString
+from dsp_tools.utils.ansi_colors import BOLD
+from dsp_tools.utils.ansi_colors import RESET_TO_DEFAULT
 from dsp_tools.utils.json_parsing import parse_json_input
 
+load_dotenv()
 
-def create_project(  # noqa: PLR0915 (too many statements)
+
+def create_project(  # noqa: PLR0915,PLR0912 (too many statements & branches)
     project_file_as_path_or_parsed: str | Path | dict[str, Any],
     creds: ServerCredentials,
     verbose: bool = False,
@@ -65,80 +83,92 @@ def create_project(  # noqa: PLR0915 (too many statements)
     knora_api_prefix = "knora-api:"
     overall_success = True
 
+    # includes validation
+    parsed_project = parse_project(project_file_as_path_or_parsed, creds.server)
+    if not isinstance(parsed_project, ParsedProject):
+        for problem in parsed_project:
+            print_problem_collection(problem)
+        return False
+
+    # required for the legacy code
     project_json = parse_json_input(project_file_as_path_or_parsed=project_file_as_path_or_parsed)
-
     context = Context(project_json.get("prefixes", {}))
-
-    # validate against JSON schema
-    validate_project(project_json)
-    print("    JSON project file is syntactically correct and passed validation.")
-    logger.info("JSON project file is syntactically correct and passed validation.")
-
-    project = parse_project_json(project_json)
+    legacy_project = parse_project_json(project_json)
 
     auth = AuthenticationClientLive(creds.server, creds.user, creds.password)
     con = ConnectionLive(creds.server, auth)
 
     # create project on DSP server
-    info_str = f"Create project '{project.metadata.shortname}' ({project.metadata.shortcode})..."
-    print(info_str)
+    info_str = f"Create project '{legacy_project.metadata.shortname}' ({legacy_project.metadata.shortcode}):"
+    print(BOLD + info_str + RESET_TO_DEFAULT)
     logger.info(info_str)
     project_remote, success = _create_project_on_server(
-        project_definition=project.metadata,
+        project_definition=legacy_project.metadata,
         con=con,
     )
+    project_iri = cast(str, project_remote.iri)
+    project_iri_lookup = ProjectIriLookup(project_iri)
     if not success:
         overall_success = False
 
     # create the lists
-    names_and_iris_of_list_nodes: dict[str, Any] = {}
-    if project.lists:
-        print("Create lists...")
-        logger.info("Create lists...")
-        names_and_iris_of_list_nodes, success = create_lists_on_server(
-            lists_to_create=project.lists,
-            con=con,
-            project_remote=project_remote,
+    if parsed_project.lists:
+        list_name_2_iri, list_problems = create_lists(
+            parsed_lists=parsed_project.lists,
+            shortcode=parsed_project.project_metadata.shortcode,
+            auth=auth,
+            project_iri=project_iri,
         )
-        if not success:
+        if list_problems:
             overall_success = False
+            print_problem_collection(list_problems)
+    else:
+        list_name_2_iri = get_existing_lists_on_server(parsed_project.project_metadata.shortcode, auth)
 
     # create the groups
-    current_project_groups: dict[str, Group] = {}
-    if project.groups:
-        print("Create groups...")
-        logger.info("Create groups...")
-        current_project_groups, success = _create_groups(
-            con=con,
-            groups=project.groups,
-            project=project_remote,
+    group_client = GroupClientLive(creds.server, auth)
+    group_lookup = get_existing_group_to_iri_lookup(
+        group_client, project_iri, parsed_project.project_metadata.shortname
+    )
+    if parsed_project.groups:
+        group_lookup, group_problems = create_groups(
+            groups=parsed_project.groups,
+            group_client=group_client,
+            project_iri=project_iri,
+            group_lookup=group_lookup,
         )
-        if not success:
+        if group_problems:
+            print_problem_collection(group_problems)
             overall_success = False
 
     # create or update the users
-    if project.users:
+    if legacy_project.users:
         print("Create users...")
         logger.info("Create users...")
-        success = _create_users(
+        success, user_problems = _create_users(
             con=con,
-            users_section=project.users,
-            current_project_groups=current_project_groups,
+            users_section=legacy_project.users,
+            group_lookup=group_lookup,
             current_project=project_remote,
             verbose=verbose,
         )
         if not success:
             overall_success = False
+        if user_problems:
+            print_problem_collection(user_problems)
 
     # create the ontologies
     success = create_ontologies(
         con=con,
         context=context,
         knora_api_prefix=knora_api_prefix,
-        names_and_iris_of_list_nodes=names_and_iris_of_list_nodes,
-        ontology_definitions=project.ontologies,
+        list_name_2_iri=list_name_2_iri,
+        ontology_definitions=legacy_project.ontologies,
         project_remote=project_remote,
         verbose=verbose,
+        parsed_ontologies=parsed_project.ontologies,
+        project_iri_lookup=project_iri_lookup,
+        auth=auth,
     )
     if not success:
         overall_success = False
@@ -147,9 +177,9 @@ def create_project(  # noqa: PLR0915 (too many statements)
     perm_client = PermissionsClient(auth, str(project_remote.iri))
     success = create_default_permissions(
         perm_client,
-        project.metadata.default_permissions,
-        project.metadata.default_permissions_overrule,
-        project.metadata.shortcode,
+        legacy_project.metadata.default_permissions,
+        legacy_project.metadata.default_permissions_overrule,
+        legacy_project.metadata.shortcode,
     )
     if not success:
         overall_success = False
@@ -157,15 +187,15 @@ def create_project(  # noqa: PLR0915 (too many statements)
     # final steps
     if overall_success:
         msg = (
-            f"Successfully created project '{project.metadata.shortname}' "
-            f"({project.metadata.shortcode}) with all its ontologies. "
+            f"Successfully created project '{legacy_project.metadata.shortname}' "
+            f"({legacy_project.metadata.shortcode}) with all its ontologies. "
             f"There were no problems during the creation process."
         )
         print(f"========================================================\n{msg}")
         logger.info(msg)
     else:
         msg = (
-            f"The project '{project.metadata.shortname}' ({project.metadata.shortcode}) "
+            f"The project '{legacy_project.metadata.shortname}' ({legacy_project.metadata.shortcode}) "
             f"with its ontologies could be created, "
             f"but during the creation process, some problems occurred. Please carefully check the console output."
         )
@@ -229,87 +259,13 @@ def _create_project_on_server(
     return project_remote, success
 
 
-def _create_groups(
-    con: Connection,
-    groups: list[dict[str, str]],
-    project: Project,
-) -> tuple[dict[str, Group], bool]:
-    """
-    Creates groups on a DSP server from the "groups" section of a JSON project file. If a group cannot be created, it is
-    skipped and a warning is printed, but such a group will still be part of the returned dict.
-    Returns a tuple consisting of a dict and a bool. The dict contains the groups that have successfully been created
-    (or already exist). The bool indicates if everything went smoothly during the process. If a warning or error
-    occurred, it is False.
-
-    Args:
-        con: connection instance to connect to the DSP server
-        groups: "groups" section of a parsed JSON project file
-        project: Project the group(s) should be added to (must exist on DSP server)
-
-    Returns:
-        A tuple consisting of a dict and the success status.
-        The dict has the form ``{group name: group object}``
-        for all groups that have successfully been created (or already exist).
-        The dict is empty if no group was created.
-    """
-    overall_success = True
-    current_project_groups: dict[str, Group] = {}
-    try:
-        remote_groups = Group.getAllGroupsForProject(con=con, proj_iri=str(project.iri))
-    except BaseError:
-        err_msg = (
-            "Unable to check if group names are already existing on DSP server, because it is "
-            "not possible to retrieve the remote groups from the DSP server."
-        )
-        print(f"WARNING: {err_msg}")
-        logger.exception(err_msg)
-        remote_groups = []
-        overall_success = False
-
-    for group in groups:
-        group_name = group["name"]
-
-        # if the group already exists, add it to "current_project_groups" (for later usage), then skip it
-        if remotely_existing_group := [g for g in remote_groups if g.name == group_name]:
-            current_project_groups[group_name] = remotely_existing_group[0]
-            err_msg = f"Group name '{group_name}' already exists on the DSP server. Skipping..."
-            print(f"    WARNING: {err_msg}")
-            logger.warning(err_msg)
-            overall_success = False
-            continue
-
-        # create the group
-        group_local = Group(
-            con=con,
-            name=group_name,
-            descriptions=LangString(group["descriptions"]),
-            project=project,
-            status=bool(group.get("status", True)),
-            selfjoin=bool(group.get("selfjoin", False)),
-        )
-        try:
-            group_remote: Group = group_local.create()
-        except BaseError:
-            err_msg = "Unable to create group '{group_name}'."
-            print(f"    WARNING: {err_msg}")
-            logger.exception(err_msg)
-            overall_success = False
-            continue
-
-        current_project_groups[str(group_remote.name)] = group_remote
-        print(f"    Created group '{group_name}'.")
-        logger.info(f"Created group '{group_name}'.")
-
-    return current_project_groups, overall_success
-
-
 def _create_users(
     con: Connection,
     users_section: list[dict[str, str]],
-    current_project_groups: dict[str, Group],
+    group_lookup: GroupNameToIriLookup,
     current_project: Project,
     verbose: bool,
-) -> bool:
+) -> tuple[bool, CollectedProblems | None]:
     """
     Creates users on a DSP server from the "users" section of a JSON project file.
     If a user cannot be created, a warning is printed and the user is skipped.
@@ -317,28 +273,29 @@ def _create_users(
     Args:
         con: connection instance to connect to the DSP server
         users_section: "users" section of a parsed JSON project file
-        current_project_groups: groups defined in the current project, in the form ``{group name: group object}``
-            (must exist on DSP server)
+        group_lookup: groups defined in the current project
         current_project: "project" object of the current project (must exist on DSP server)
         verbose: Prints more information if set to True
 
     Returns:
         True if all users could be created without any problems. False if a warning/error occurred.
     """
+    group_problems: list[CreateProblem] = []
     overall_success = True
     all_users = User.getAllUsers(con)
     for json_user_definition in users_section:
         username = json_user_definition["username"]
 
-        group_iris, success = _get_group_iris_for_user(
-            json_user_definition=json_user_definition,
-            current_project=current_project,
-            current_project_groups=current_project_groups,
-            con=con,
-            verbose=verbose,
-        )
-        if not success:
-            overall_success = False
+        group_iris = set()
+        if found_groups := json_user_definition.get("groups"):
+            for gr in found_groups:
+                gr_name = gr.removeprefix(":")
+                if gr_found := group_lookup.get_iri(gr_name):
+                    group_iris.add(gr_found)
+                else:
+                    group_problems.append(
+                        UploadProblem(f"User: '{username}' / Group: '{gr}'", ProblemType.GROUP_NOT_FOUND)
+                    )
 
         project_info, success = _get_projects_where_user_is_admin(
             json_user_definition=json_user_definition,
@@ -354,13 +311,26 @@ def _create_users(
             continue
 
         # create the user
+        user_name = json_user_definition["username"]
+        pw = json_user_definition["password"]
+        if not pw:
+            default_pw = os.getenv("DSP_USER_PASSWORD")
+            if not default_pw:
+                print(
+                    f"    User with the user name '{user_name}' could not be created "
+                    f"as no password is specified and no default password is saved in a .env file."
+                )
+                overall_success = False
+                continue
+            else:
+                pw = str(default_pw)
         user_local = User(
             con=con,
-            username=json_user_definition["username"],
+            username=user_name,
             email=json_user_definition["email"],
             givenName=json_user_definition["givenName"],
             familyName=json_user_definition["familyName"],
-            password=json_user_definition["password"],
+            password=pw,
             status=bool(json_user_definition.get("status", True)),
             lang=json_user_definition.get("lang", "en"),
             in_projects=project_info,
@@ -374,8 +344,10 @@ def _create_users(
             print(f"    WARNING: Unable to create user '{username}'.")
             logger.exception(f"Unable to create user '{username}'.")
             overall_success = False
-
-    return overall_success
+    if group_problems:
+        probs = CollectedProblems("During the creation of the users the following problems occurred:", group_problems)
+        return False, probs
+    return overall_success, None
 
 
 def _add_user_to_groups_and_project(
@@ -422,88 +394,6 @@ def _add_user_to_groups_and_project(
             logger.warning(err_msg)
 
 
-def _get_group_iris_for_user(
-    json_user_definition: dict[str, str],
-    current_project: Project,
-    current_project_groups: dict[str, Group],
-    con: Connection,
-    verbose: bool,
-) -> tuple[set[str], bool]:
-    """
-    Retrieve the IRIs of the groups that the user belongs to.
-
-    Args:
-        json_user_definition: the section of the JSON file that defines a user
-        current_project: the Project object
-        current_project_groups: dict of the form ``{group name: group object}``
-            with the groups that exist on the DSP server
-        con: connection to the DSP server
-        verbose: verbose switch
-
-    Returns:
-        a tuple consisting of the group IRIs,
-        and the success status (True if everything went well)
-
-    Raises:
-        BaseError: if no groups can be retrieved from the DSP server, or if the retrieved group has no IRI
-    """
-    success = True
-    username = json_user_definition["username"]
-    group_iris: set[str] = set()
-    remote_groups: list[Group] = []
-    for full_group_name in json_user_definition.get("groups", []):
-        # full_group_name has the form '[project_shortname]:group_name'
-        inexisting_group_msg = (
-            f"User {username} cannot be added to group {full_group_name}, because such a group doesn't exist."
-        )
-        if ":" not in full_group_name:
-            print(f"    WARNING: {inexisting_group_msg}")
-            logger.warning(inexisting_group_msg)
-            success = False
-            continue
-
-        # all other cases (":" in full_group_name)
-        project_shortname, group_name = full_group_name.split(":")
-        if not project_shortname:
-            # full_group_name refers to a group inside the same project
-            if group_name not in current_project_groups:
-                print(f"    WARNING: {inexisting_group_msg}")
-                logger.warning(inexisting_group_msg)
-                success = False
-                continue
-            group = current_project_groups[group_name]
-        else:
-            # full_group_name refers to an already existing group on DSP
-            try:
-                # "remote_groups" might be available from a previous loop cycle
-                remote_groups = remote_groups or Group.getAllGroups(con=con)
-            except BaseError:
-                err_msg = (
-                    f"User '{username}' is referring to the group {full_group_name} that "
-                    f"exists on the DSP server, but no groups could be retrieved from the DSP server."
-                )
-                print(f"    WARNING: {err_msg}")
-                logger.exception(err_msg)
-                success = False
-                continue
-            existing_group = [g for g in remote_groups if g.project == current_project.iri and g.name == group_name]
-            if not existing_group:
-                print(f"    WARNING: {inexisting_group_msg}")
-                logger.warning(inexisting_group_msg)
-                success = False
-                continue
-            group = existing_group[0]
-
-        if not group.iri:
-            raise BaseError(f"Group '{group}' has no IRI.")
-        group_iris.add(group.iri)
-        if verbose:
-            print(f"    Added user '{username}' to group '{full_group_name}'.")
-        logger.info(f"Added user '{username}' to group '{full_group_name}'.")
-
-    return group_iris, success
-
-
 def _get_projects_where_user_is_admin(
     json_user_definition: dict[str, str],
     current_project: Project,
