@@ -7,11 +7,12 @@ from loguru import logger
 
 from dsp_tools.clients.authentication_client import AuthenticationClient
 from dsp_tools.clients.connection import Connection
-from dsp_tools.clients.ontology_client_live import OntologyClientLive
+from dsp_tools.clients.ontology_create_client_live import OntologyCreateClientLive
 from dsp_tools.commands.create.communicate_problems import print_problem_collection
 from dsp_tools.commands.create.create_on_server.cardinalities import add_all_cardinalities
 from dsp_tools.commands.create.models.parsed_ontology import ParsedOntology
 from dsp_tools.commands.create.models.server_project_info import CreatedIriCollection
+from dsp_tools.commands.create.models.server_project_info import ListNameToIriLookup
 from dsp_tools.commands.create.models.server_project_info import ProjectIriLookup
 from dsp_tools.commands.project.legacy_models.context import Context
 from dsp_tools.commands.project.legacy_models.ontology import Ontology
@@ -22,13 +23,15 @@ from dsp_tools.error.exceptions import BaseError
 from dsp_tools.error.exceptions import InputError
 from dsp_tools.legacy_models.datetimestamp import DateTimeStamp
 from dsp_tools.legacy_models.langstring import LangString
+from dsp_tools.utils.ansi_colors import BOLD
+from dsp_tools.utils.ansi_colors import RESET_TO_DEFAULT
 
 
 def create_ontologies(
     con: Connection,
     context: Context,
     knora_api_prefix: str,
-    names_and_iris_of_list_nodes: dict[str, Any],
+    list_name_2_iri: ListNameToIriLookup,
     ontology_definitions: list[dict[str, Any]],
     project_remote: Project,
     verbose: bool,
@@ -45,7 +48,7 @@ def create_ontologies(
         con: Connection to the DSP server
         context: prefixes and the ontology IRIs they stand for
         knora_api_prefix: the prefix that stands for the knora-api ontology
-        names_and_iris_of_list_nodes: IRIs of list nodes that were already created and are available on the DSP server
+        list_name_2_iri: IRIs of list nodes that were already created and are available on the DSP server
         ontology_definitions: the "ontologies" section of the parsed JSON project file
         project_remote: representation of the project on the DSP server
         verbose: verbose switch
@@ -61,17 +64,15 @@ def create_ontologies(
         True if everything went smoothly, False otherwise
     """
     success_collection = CreatedIriCollection()
-    onto_client = OntologyClientLive(auth.server, auth)
+    onto_client = OntologyCreateClientLive(auth.server, auth)
 
     overall_success = True
-
-    print("Create ontologies...")
-    logger.info("Create ontologies...")
+    logger.info("Processing Ontology Section")
     try:
         project_ontologies = Ontology.getProjectOntologies(con=con, project_id=str(project_remote.iri))
     except BaseError:
         err_msg = "Unable to retrieve remote ontologies. Cannot check if your ontology already exists."
-        print("WARNING: {err_msg}")
+        print(f"    WARNING: {err_msg}")
         logger.exception(err_msg)
         project_ontologies = []
 
@@ -114,7 +115,7 @@ def create_ontologies(
             onto_name=ontology_definition["name"],
             property_definitions=ontology_definition.get("properties", []),
             ontology_remote=ontology_remote,
-            names_and_iris_of_list_nodes=names_and_iris_of_list_nodes,
+            list_name_2_iri=list_name_2_iri,
             con=con,
             last_modification_date=last_modification_date,
             knora_api_prefix=knora_api_prefix,
@@ -125,7 +126,7 @@ def create_ontologies(
         if not success:
             overall_success = False
 
-    print("Add cardinalities to resource classes...")
+    print(BOLD + "Processing Cardinalities:" + RESET_TO_DEFAULT)
     problems = add_all_cardinalities(
         ontologies=parsed_ontologies,
         project_iri_lookup=project_iri_lookup,
@@ -173,12 +174,12 @@ def _create_ontology(
     # skip if it already exists on the DSP server
     if onto_name in [onto.name for onto in project_ontologies]:
         err_msg = f"Ontology '{onto_name}' already exists on the DSP server. Skipping..."
-        print(f"    WARNING: {err_msg}")
+        print(f"WARNING: {err_msg}")
         logger.warning(err_msg)
         return None
 
-    print(f"Create ontology '{onto_name}'...")
-    logger.info(f"Create ontology '{onto_name}'...")
+    print(BOLD + f"Processing ontology '{onto_name}':" + RESET_TO_DEFAULT)
+    logger.info(f"Processing ontology '{onto_name}'")
     ontology_local = Ontology(
         con=con,
         project=project_remote,
@@ -308,11 +309,11 @@ def _sort_resources(
     return sorted_resources
 
 
-def _add_property_classes_to_remote_ontology(
+def _add_property_classes_to_remote_ontology(  # noqa: PLR0912
     onto_name: str,
     property_definitions: list[dict[str, Any]],
     ontology_remote: Ontology,
-    names_and_iris_of_list_nodes: dict[str, Any],
+    list_name_2_iri: ListNameToIriLookup,
     con: Connection,
     last_modification_date: DateTimeStamp,
     knora_api_prefix: str,
@@ -328,7 +329,7 @@ def _add_property_classes_to_remote_ontology(
         onto_name: name of the current ontology
         property_definitions: the part of the parsed JSON project file that contains the properties of the current onto
         ontology_remote: representation of the current ontology on the DSP server
-        names_and_iris_of_list_nodes: IRIs of list nodes that were already created and are available on the DSP server
+        list_name_2_iri: IRIs of list nodes that were already created and are available on the DSP server
         con: connection to the DSP server
         last_modification_date: last modification date of the ontology on the DSP server
         knora_api_prefix: the prefix that stands for the knora-api ontology
@@ -373,7 +374,18 @@ def _add_property_classes_to_remote_ontology(
         # get the gui_attributes
         gui_attributes = prop_class.get("gui_attributes")
         if gui_attributes and gui_attributes.get("hlist"):
-            list_iri = names_and_iris_of_list_nodes[gui_attributes["hlist"]]["id"]
+            list_name = gui_attributes["hlist"]
+            list_iri = list_name_2_iri.get_iri(list_name)
+            if not list_iri:
+                err_msg = (
+                    f"Unable to create property class '{prop_class['name']}' "
+                    f"because the list with the name '{list_name}' does not exist on the server."
+                )
+                print(f"    WARNING: {err_msg}")
+                logger.warning(err_msg)
+                overall_success = False
+                continue
+
             gui_attributes["hlist"] = f"<{list_iri}>"
 
         # create the property class
@@ -405,7 +417,7 @@ def _add_property_classes_to_remote_ontology(
                 err.message,
             ):
                 err_msg += f", because it refers to a class of another project: '{found.group(1)}'."
-            print(f"WARNING: {err_msg}")
+            print(f"    WARNING: {err_msg}")
             logger.exception(err_msg)
             overall_success = False
 
