@@ -5,6 +5,8 @@ from dataclasses import dataclass
 from rdflib import Graph
 from rdflib import URIRef
 
+from dsp_tools.clients.list_client import OneList
+
 
 @dataclass
 class SHACLValidationReport:
@@ -16,6 +18,7 @@ class SHACLValidationReport:
 class ProjectDataFromApi:
     all_lists: list[OneList]
     enabled_licenses: EnabledLicenseIris
+    resource_iris_in_db: list[InfoForResourceInDB]
 
 
 @dataclass
@@ -23,22 +26,6 @@ class ListLookup:
     lists: dict[tuple[str, str], str]
 
 
-@dataclass
-class OneList:
-    list_iri: str
-    list_name: str
-    nodes: list[OneNode]
-
-    def hlist(self) -> str:
-        return f'"hlist=<{self.list_iri}>"'
-
-
-@dataclass
-class OneNode:
-    name: str
-    iri: str
-
-
 @dataclass
 class SHACLListInfo:
     list_iri: URIRef
@@ -50,3 +37,9 @@ class SHACLListInfo:
 @dataclass
 class EnabledLicenseIris:
     enabled_licenses: list[str]
+
+
+@dataclass
+class InfoForResourceInDB:
+    res_iri: str
+    res_type: str
