@@ -33,7 +33,7 @@ def get_parsed_resources_and_mappers(
 
 def _get_xml_reference_lookups(root: etree._Element, clients: UploadClients) -> XmlReferenceLookups:
     proj_context = _get_project_context_from_server(
-        connection=clients.project_client.con, shortcode=root.attrib["shortcode"]
+        connection=clients.list_client.con, shortcode=root.attrib["shortcode"]
     )
     permissions_lookup = get_permissions_lookup(root, proj_context)
     authorship_lookup = get_authorship_lookup(root)
