@@ -21,11 +21,14 @@ from dsp_tools.clients.connection_live import ConnectionLive
 from dsp_tools.clients.fuseki_metrics import FusekiMetrics
 from dsp_tools.clients.legal_info_client import LegalInfoClient
 from dsp_tools.clients.legal_info_client_live import LegalInfoClientLive
+from dsp_tools.clients.project_client import ProjectInfoClient
+from dsp_tools.clients.project_client_live import ProjectInfoClientLive
 from dsp_tools.commands.validate_data.validate_data import validate_parsed_resources
 from dsp_tools.commands.xmlupload.make_rdf_graph.make_resource_and_values import create_resource_with_values
 from dsp_tools.commands.xmlupload.models.ingest import AssetClient
 from dsp_tools.commands.xmlupload.models.ingest import DspIngestClientLive
 from dsp_tools.commands.xmlupload.models.lookup_models import IRILookups
+from dsp_tools.commands.xmlupload.models.lookup_models import XmlReferenceLookups
 from dsp_tools.commands.xmlupload.models.processed.res import ProcessedResource
 from dsp_tools.commands.xmlupload.models.upload_clients import UploadClients
 from dsp_tools.commands.xmlupload.models.upload_state import UploadState
@@ -36,8 +39,6 @@ from dsp_tools.commands.xmlupload.prepare_xml_input.prepare_xml_input import get
 from dsp_tools.commands.xmlupload.prepare_xml_input.prepare_xml_input import get_stash_and_upload_order
 from dsp_tools.commands.xmlupload.prepare_xml_input.read_validate_xml_file import check_if_bitstreams_exist
 from dsp_tools.commands.xmlupload.prepare_xml_input.read_validate_xml_file import validate_iiif_uris
-from dsp_tools.commands.xmlupload.project_client import ProjectClient
-from dsp_tools.commands.xmlupload.project_client import ProjectClientLive
 from dsp_tools.commands.xmlupload.resource_create_client import ResourceCreateClient
 from dsp_tools.commands.xmlupload.stash.upload_stashed_resptr_props import upload_stashed_resptr_props
 from dsp_tools.commands.xmlupload.stash.upload_stashed_xml_texts import upload_stashed_xml_texts
@@ -54,6 +55,7 @@ from dsp_tools.utils.ansi_colors import BOLD_YELLOW
 from dsp_tools.utils.ansi_colors import RESET_TO_DEFAULT
 from dsp_tools.utils.data_formats.uri_util import is_prod_like_server
 from dsp_tools.utils.fuseki_bloating import communicate_fuseki_bloating
+from dsp_tools.utils.replace_id_with_iri import use_id2iri_mapping_to_replace_ids
 from dsp_tools.utils.xml_parsing.models.parsed_resource import ParsedResource
 from dsp_tools.utils.xml_parsing.parse_clean_validate_xml import parse_and_clean_xml_file
 
@@ -92,8 +94,49 @@ def xmlupload(
     clients = _get_live_clients(con, auth, creds, shortcode, imgdir)
 
     parsed_resources, lookups = get_parsed_resources_and_mappers(root, clients)
+    if config.id2iri_file:
+        parsed_resources = use_id2iri_mapping_to_replace_ids(parsed_resources, Path(config.id2iri_file))
 
     is_on_prod_like_server = is_prod_like_server(creds.server)
+
+    validation_ok = _handle_validation(
+        parsed_resources=parsed_resources,
+        lookups=lookups,
+        config=config,
+        is_on_prod_like_server=is_on_prod_like_server,
+        auth=auth,
+        input_file=input_file,
+    )
+    if not validation_ok:
+        return False
+
+    check_if_bitstreams_exist(root, imgdir)
+    if not config.skip_iiif_validation:
+        validate_iiif_uris(root)
+
+    if not is_on_prod_like_server:
+        enable_unknown_license_if_any_are_missing(clients.legal_info_client, parsed_resources)
+
+    processed_resources = get_processed_resources(parsed_resources, lookups, is_on_prod_like_server)
+
+    sorted_resources, stash = get_stash_and_upload_order(processed_resources)
+    state = UploadState(
+        pending_resources=sorted_resources,
+        pending_stash=stash,
+        config=config,
+    )
+
+    return execute_upload(clients, state)
+
+
+def _handle_validation(
+    parsed_resources: list[ParsedResource],
+    lookups: XmlReferenceLookups,
+    config: UploadConfig,
+    is_on_prod_like_server: bool,
+    auth: AuthenticationClient,
+    input_file: Path,
+) -> bool:
     validation_should_be_skipped = config.skip_validation
     if is_on_prod_like_server and config.skip_validation:
         msg = (
@@ -126,7 +169,7 @@ def xmlupload(
             parsed_resources=parsed_resources,
             authorship_lookup=lookups.authorships,
             permission_ids=list(lookups.permissions.keys()),
-            shortcode=shortcode,
+            shortcode=config.shortcode,
             config=ValidateDataConfig(
                 input_file,
                 save_graph_dir=None,
@@ -134,6 +177,7 @@ def xmlupload(
                 ignore_duplicate_files_warning=ignore_duplicates,
                 is_on_prod_server=is_on_prod_like_server,
                 skip_ontology_validation=config.skip_ontology_validation,
+                do_not_request_resource_metadata_from_db=config.do_not_request_resource_metadata_from_db,
             ),
             auth=auth,
         )
@@ -141,24 +185,7 @@ def xmlupload(
             return False
     else:
         logger.debug("SHACL validation was skipped.")
-
-    check_if_bitstreams_exist(root, imgdir)
-    if not config.skip_iiif_validation:
-        validate_iiif_uris(root)
-
-    if not is_on_prod_like_server:
-        enable_unknown_license_if_any_are_missing(clients.legal_info_client, parsed_resources)
-
-    processed_resources = get_processed_resources(parsed_resources, lookups, is_on_prod_like_server)
-
-    sorted_resources, stash = get_stash_and_upload_order(processed_resources)
-    state = UploadState(
-        pending_resources=sorted_resources,
-        pending_stash=stash,
-        config=config,
-    )
-
-    return execute_upload(clients, state)
+    return True
 
 
 def _get_live_clients(
@@ -170,12 +197,11 @@ def _get_live_clients(
 ) -> UploadClients:
     ingest_client: AssetClient
     ingest_client = DspIngestClientLive(creds.dsp_ingest_url, auth, shortcode, imgdir)
-    project_client: ProjectClient = ProjectClientLive(con, shortcode)
-    list_client: ListClient = ListClientLive(con, project_client.get_project_iri())
+    project_client: ProjectInfoClient = ProjectInfoClientLive(auth.server)
+    list_client: ListClient = ListClientLive(con, project_client.get_project_iri(shortcode))
     legal_info_client: LegalInfoClient = LegalInfoClientLive(creds.server, shortcode, auth)
     return UploadClients(
         asset_client=ingest_client,
-        project_client=project_client,
         list_client=list_client,
         legal_info_client=legal_info_client,
     )
@@ -288,7 +314,7 @@ def _upload_resources(clients: UploadClients, upload_state: UploadState) -> None
         BaseException: in case of an unhandled exception during resource creation
         XmlUploadInterruptedError: if the number of resources created is equal to the interrupt_after value
     """
-    project_iri = clients.project_client.get_project_iri()
+    project_iri = clients.list_client.project_iri
 
     iri_lookup = IRILookups(
         project_iri=URIRef(project_iri),
@@ -296,7 +322,7 @@ def _upload_resources(clients: UploadClients, upload_state: UploadState) -> None
     )
 
     resource_create_client = ResourceCreateClient(
-        con=clients.project_client.con,
+        con=clients.list_client.con,
     )
     progress_bar = tqdm(upload_state.pending_resources.copy(), desc="Creating Resources", dynamic_ncols=True)
     try:
@@ -311,19 +337,19 @@ def _upload_resources(clients: UploadClients, upload_state: UploadState) -> None
             )
             progress_bar.set_description(f"Creating Resources (failed: {len(upload_state.failed_uploads)})")
         if upload_state.pending_stash:
-            _upload_stash(upload_state, clients.project_client)
+            _upload_stash(upload_state, clients.list_client.con)
     except XmlUploadInterruptedError as err:
         _handle_upload_error(err, upload_state)
 
 
 def _upload_stash(
     upload_state: UploadState,
-    project_client: ProjectClient,
+    con: Connection,
 ) -> None:
     if upload_state.pending_stash and upload_state.pending_stash.standoff_stash:
-        upload_stashed_xml_texts(upload_state, project_client.con)
+        upload_stashed_xml_texts(upload_state, con)
     if upload_state.pending_stash and upload_state.pending_stash.link_value_stash:
-        upload_stashed_resptr_props(upload_state, project_client.con)
+        upload_stashed_resptr_props(upload_state, con)
 
 
 def _upload_one_resource(
