@@ -91,10 +91,12 @@ class Resource:
             ```
         """
         if not is_valid_resource_id(res_id):
+            res_id = str(res_id)
             emit_xmllib_input_type_mismatch_warning(
                 expected_type="xsd:ID", value=res_id, res_id=res_id, value_field="resource ID"
             )
         if not is_nonempty_value(restype):
+            restype = str(restype)
             emit_xmllib_input_type_mismatch_warning(
                 expected_type="resource type", value=restype, res_id=res_id, value_field="restype"
             )
@@ -1778,49 +1780,3 @@ class Resource:
         )
         self.file_value = IIIFUri.new(value=iiif_uri, metadata=meta, comment=comment, resource_id=self.res_id)
         return self
-
-    #######################
-    # Migration Metadata
-    #######################
-
-    def add_migration_metadata(
-        self, creation_date: str | None, iri: str | None = None, ark: str | None = None
-    ) -> Resource:
-        """
-        Add metadata from a SALSAH migration.
-
-        [See XML documentation for details](https://docs.dasch.swiss/latest/DSP-TOOLS/file-formats/xml-data-file/#describing-resources-with-the-resource-element)
-
-        Args:
-            creation_date: creation date of the resource in SALSAH
-            iri: Original IRI in SALSAH
-            ark: Original ARK in SALSAH
-
-        Raises:
-            XmllibInputError: if metadata already exists
-
-        Returns:
-            The original resource, with the added migration metadata
-
-        Examples:
-            ```python
-            resource = resource.add_migration_metadata(
-                iri="http://rdfh.ch/4123/DiAmYQzQSzC7cdTo6OJMYA",
-                creation_date="1999-12-31T23:59:59.9999999+01:00"
-            )
-            ```
-
-            ```python
-            resource = resource.add_migration_metadata(
-                ark="ark:/72163/4123-43xc6ivb931-a.2022829",
-                creation_date="1999-12-31T23:59:59.9999999+01:00"
-            )
-            ```
-        """
-        if self.migration_metadata:
-            msg_info = MessageInfo(
-                "This resource already contains migration metadata, no new data can be added.", resource_id=self.res_id
-            )
-            raise_xmllib_input_error(msg_info)
-        self.migration_metadata = MigrationMetadata(creation_date=creation_date, iri=iri, ark=ark, res_id=self.res_id)
-        return self
